/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Sun 101-A keyboard.
 * By Christopher Davis <ckd@kei.com>
 */

static const KeyCode sun101a_codes [] = {

  /* Row 0 */
  36,
  12, 13, 15, 17,
  19, 21, 23, 24,
  25, 14, 16, 18,
  29, 30, 8,

  /* Row 2 */
  49, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 73,
  32, 104, 58,
  105, 53, 54, 78,

  /* Row 3 */
  60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 95,
  125, 33, 80,
  75, 76, 77, 132,
  
  /* Row 4 */
  126, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 96,
  98, 99, 100,

  /* Row 5 */
  106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117,
  27,
  119, 120, 121, 97,

  /* Row 6 */
  83,
  127, 128, 129,
  26,
  31, 34, 35,
  101, 57
};
